@@ -409,7 +409,7 @@ static int setparams(snd_pcm_t *phandle, snd_pcm_t *chandle,
     }
 
     if (verbose) {
-	fprintf(error_fp, "alsa: Negociated configuration:\n");
+	fprintf(error_fp, "alsa: Negotiated configuration:\n");
 	snd_pcm_dump_setup(phandle, output);
 	snd_pcm_dump_setup(chandle, output);
 	fprintf(error_fp, "alsa: Parameters are %iHz, %s, %i channels\n",
